function [sAIR] ...
   = f_AirDistance_AEO(...
                    N, vLOF_AEO,v3, ...
                    Sw, k_TO, ...
                    CD0clean, d_CD0_gear, d_CD0_flaps, CLmaxTO, ...
                    alpha,m, ...
                    F0,BPR,b, ...
                    deltaT,rho,H)


... acceleration assumed to be linear from vR to v3
vTR   = (vLOF_AEO+v3)/2; %average transition speed

g  = 9.80665;
W=m*g;
% AR   = b^2/Sw;  % aspect ratio
% alphaRad = alpha*pi/180; %angle of attack

% N   =  %operating engines

p0     = 101325;
R      = 287.058; % gas constant
kappa  = 1.4; %constant, air
L      = 0.0065; %temperature gradient {°/m]
T0     = 288.15 + deltaT; % temperature (msl) {K]

% Young 2008
p = p0*(1-H*L/T0)^(g/(R*L)); % pressure
A = -0.4327*(p/p0).^2+1.3855*(p/p0)+0.0472 ; % thrust factor
X = 0.1377*(p/p0).^2-0.4374*(p/p0)+1.3003; % thrust factor
Z = 0.9106*(p/p0).^2-1.7736*(p/p0)+1.8697; % thrust factor
T = T0-L*H; % temperature as a function of height
c = sqrt(R*kappa*T); %speed of sound

... linear G-factor function: 
G = 0.061*BPR + 0.633; % gas generator factor:Young 2008 => A340, BPR=7.6
... determined in excel with 2 values of the original figure 
    
M   = (vTR/c); % mach number
M2  = (v3/c);  %regarding 2nd climb gradient
K1  =  (((0.377*(1+BPR))  /   sqrt((1+0.82*BPR)*G)))*Z * (p/p0); % thrust factor
K2  =  (0.23+0.19*sqrt(BPR)).*X.*p/p0 ; % thrust factor
F   = N*F0*( A - K1*(M)  +    K2*(M).^2)  ; %Bartels & Young (genauer - konservativer)
F2  = N*F0*( A - K1*(M2)  +    K2*(M2).^2)  ; %regarding 2nd climb gradient


CL2 = 1/(0.94*1.2)^2 * (CLmaxTO);
... derived from ratio v2 / vs1g = CL2 / CLmax
... v2^2          = 2w / (rho*Sw*CL2)
... vs1g^2        = 2w / (rho*Sw*CLmax)
... v2    = 1.2 vs = 1.2*0.94 vs1g
L = rho/2*(vTR)^2*CL2*Sw; % lift

% k     = 1/(pi*e*AR);
% k_TO  = 1/(1/k+pi*AR*delta_e)

CD0       = CD0clean + d_CD0_gear + d_CD0_flaps;
CD        = CD0 + k_TO*CL2^2; 
D = rho/2*(vTR)^2*CD*Sw; 

n = 1.15; % load factor

R       = vTR^2/(g*(n-1)); % transition radius

theta   = asin((F2-D)/W);
gamma2  = asin(F/W-CD/CL2); % pitch attitude

% conversion ft => m
h_obstacle_ft  = 35;   % height in ft
h_obstacle_m   = h_obstacle_ft*0.3048; % obstacle height [m]

hSC     = h_obstacle_m; % screen height
hTR     = R*(1-cos(gamma2)); % transition height

if hTR  >= hSC 
  sTR   = sqrt(R^2-(R-hSC)^2); %transition distance
  sCL   = 0; % climb distance
else
  sTR    = R*sin(gamma2); % transition distance
  sCL    = (hSC-hTR) / tan(gamma2);  % climb distance
end

sAIR    = sTR + sCL;  % total air distance

return