function sdot = f_GroundRollDistance_AEO(t,S,...
                    N, m,...
                    Sw,k_TO,h,b,...
                    CD0,CL0,CLalpha,...
                    alpha,gamma,...
                    mu,rho,...
                    vW,...
                    F0,BPR, ...
                    deltaT,H) 

%   t => independent variable 
%   x => dependent
%        n*2 vector (y / y')

%   y'' = v' =  a
%   y'  = v  =  v
%   y   =       s

s  = S(1); 
vG = S(2); % v = s'
v  = vG + vW;

% inflow velocity v=vG+vW
% vG=S(2) ground roll speed (regarding runway) [m/s]

% N  operting engines

g  = 9.80665;
W  =  m*g;
AR = b^2/Sw; 

alphaRad = alpha*pi/180; 

gammaRad = gamma*pi/180; 

p0    = 101325;  % ICAO,SL 
R     = 287.058;
L     = 0.0065;
T0    = 288.15; % ICAO,SL 
T0    = T0 + deltaT; % T(H=0),SL 
kappa = 1.4;

% Young 2008
p = p0*(1-H*L/T0)^(g/(R*L));
A = -0.4327*(p/p0).^2+1.3855*(p/p0)+0.0472 ;
X = 0.1377*(p/p0).^2-0.4374*(p/p0)+1.3003;
Z = 0.9106*(p/p0).^2-1.7736*(p/p0)+1.8697;
T = T0-L*H;
c = sqrt(R*kappa*T); % speed of sound

G = 0.061*BPR + 0.633; % gas generator factor:Young 2008 => A340, BPR=7.6
... determined in excel with 2 values of the original figure 

K1=  (((0.377*(1+BPR))  /   sqrt((1+0.82*BPR)*G)))*Z * (p/p0);
K2=  (0.23+0.19*sqrt(BPR)).*X.*p/p0 ;
F    = N*F0*( A - K1*(v/c)  +    K2*(v/c).^2);   %Bartels & Young (genauer - konservativer)

%M=(v/a)

%standard
% k1 = 2.44 * 10^(-4) * BPR  +  1.66 * 10^(-3);
% k2 = 6.16 * 10^(-7) * BPR  +  4.08 * 10^(-6);
% F  = N*F0*( 1 - k1*v + k2*v^2); %Scholz / Young / Roskam / ...


... ground effect:
phi = (16*h/b)^2 / (1+(16*h/b)^2);

CLg = CL0 + CLalpha*alphaRad;
L   = rho/2*(v)^2*CLg*Sw;

% delta_e=0.0026*beta;
% e=e+delta_e;
% k   = 1/(pi*e*AR);
% k_TO=1/(1/k+pi*AR*delta_e);

CDg = CD0 + phi*k_TO*CLg^2; 
D   = rho/2*(v)^2*CDg*Sw; 

Ff  = mu*(m*g*cos(gammaRad)-L); 

sdot(1,1) = vG;  % vG = s' =  ds/dt
sdot(2,1) = 1/m*(F-D-Ff)-g*sin(gammaRad); % vG' = s'' = a

return